Amplitude Session Replay Flutter SDK

Warning This SDK is currently in alpha. APIs may change and there will be breaking changes before the stable release.

This is Amplitude's Session Replay SDK for Flutter.

Installation

Add the package to your pubspec.yaml:

dependencies:
  amplitude_session_replay: ^0.1.0-beta.1

Then run:

flutter pub get

Quick Start

Wrap your app with SessionReplayWidget:

import 'package:amplitude_session_replay/amplitude_session_replay.dart';

void main() async {
  WidgetsFlutterBinding.ensureInitialized();

  final config = SessionReplayConfig(
    apiKey: 'YOUR_AMPLITUDE_API_KEY',
    deviceId: 'your-device-id',
    sessionId: DateTime.now().millisecondsSinceEpoch, // from your analytics SDK
  );

  runApp(SessionReplayWidget(config: config, app: const MyApp()));
}

Need Help?

If you have any problems or issues over our SDK, feel free to create a GitHub issue or submit a request on Amplitude Help.

Libraries

amplitude_session_replay
amplitude_session_replay_debug
amplitude_session_replay_experimental
EXPERIMENTAL — may change or be removed without notice.
constants