Constants class

Constants used by the Amplitude Session Replay SDK.

Constructors

Constants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

library String
The library identifier string in the format 'packageName/packageVersion'. Used for tracking SDK usage in analytics.
no setter

Constants

packageName → const String
The package name for the Amplitude Session Replay Flutter SDK.
packageVersion → const String
The current version of the Amplitude Session Replay Flutter SDK.